System Requirements
-------------------

Hardware requirements
~~~~~~~~~~~~~~~~~~~~~

``epiScanpy`` package requires only a standard computer with enough RAM to support the in-memory operations.

Software requirements
~~~~~~~~~~~~~~~~~~~~~

### OS Requirements
This package is supported for *macOS* and *Linux*. The package has been tested on the following systems:
+ macOS: Mojave & Catalina (10.14 to 10.15.4)



Python Dependencies
~~~~~~~~~~~~~~~~~~~
EpiScanpy require a working version of ``Python`` (>= 3.6)

Additionally, this package ``epiScanpy`` depends on other Python dependencies and packages.::

  anndata
  matplotlib
  numpy
  pandas
  pyliftOver
  pysam
  scanpy
  scipy
  scikit-learn
  seaborn
  bamnostic
  rpy2
  
  
  
  
  

